@@ -15,6 +15,12 @@ import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
 import aws_cdk.aws_s3
 import aws_cdk.core
-__all__ = []
+import constructs
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-elasticloadbalancingv2", "1.38.0", __name__[0:-6], "aws-elasticloadbalancingv2@1.38.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
